import java.awt.Color;
import java.util.Random;

/**
 * Class DrawDemo - provides some short demonstrations showing how to use the 
 * Pen class to create various drawings.
 *
 * @author Michael Kölling and David J. Barnes
 * @version 2011.07.31
 */

public class Grid extends Canvas
{
    private int gridWidth;
    private int gridHeight;

    private int cellWidth;
    private int cellHeight;

    /**
     * Prepare the drawing demo. Create a fresh canvas and make it visible.
     */
    public Grid(int gridWidth, int gridHeight, int cellWidth, int cellHeight)
    {
        super("Grid", gridWidth*(cellWidth+1), gridHeight*(cellHeight+1));
        this.gridWidth = gridWidth;
        this.gridHeight = gridHeight;
        this.cellWidth = cellWidth;
        this.cellHeight = cellHeight;            
    }

    /**
     * Draw a square on the screen.
     */
    private void fillCell(int x, int y)
    {
        setForegroundColor(Color.BLUE);
        fillRectangle(x*cellWidth+x, y*cellHeight+y, cellWidth, cellHeight);
    }

    /**
     * Draw a square on the screen.
     */
    private void eraseCell(int x, int y)
    {
        setForegroundColor(Color.WHITE);
        fillRectangle(x*cellWidth+x, y*cellHeight+y, cellWidth, cellHeight);
    }

    /**
     * Draw a board to the screen.
     * 
     * @param  board   The board as a 2-dimensional boolean array
     */
    public void drawBoard(boolean[][] board)
    {
        for (int j = 0; j < board.length; j++)
        {
            for (int i = 0; i < board[j].length; i++)
            {
                if (board[i][j])
                    fillCell(j, i);
                else
                    eraseCell(j, i);
            }
        }
        try
        {
            Thread.sleep(200);
        }
        catch (Exception e)
        {
            System.err.println(e);
        }
    }
 
    /**
     * Print a board to standard output.
     * Live cells are indicated by a "*" and dead cells by '.'
     * 
     * @param  board   The board as a 2-dimensional boolean array
     */
    public static void printBoard(boolean[][] board)
    {
        for (int i = 0; i < board.length; i++)
        {
            for (int j = 0; j < board[i].length; j++)
            {
                System.out.print(board[i][j] ? '*' : '.');
            }
            System.out.println();
        }
	}

    /**
     * Put a "glider" that travels up and to the right starting on the board
     * 
     * @param x     the starting x position
     * @param y     the starting y position
     */
    public void gliderUpRight(boolean board[][], int x, int y)
    {
        if (x > 0 && y > 0 && y < board.length - 2 && x < board[0].length - 2)
        {
            board[y][x] = true;
            board[y][x+1] = true;
            board[y][x+2] = true;
            board[y+1][x+2] = true;
            board[y+2][x] = true;
        }
    }
}
